Module: Zabby
- Defined in:
- lib/zabby/config.rb,
lib/zabby.rb,
lib/zabby/runner.rb,
lib/zabby/zclass.rb,
lib/zabby/version.rb,
lib/zabby/connection.rb,
lib/zabby/exceptions.rb,
lib/zabby/shell_helpers.rb
Overview
- Author
Farzad FARID ([email protected])
- Copyright
Copyright (c) 2011-2012 Farzad FARID
- License
Simplified BSD License
Defined Under Namespace
Modules: ShellHelpers, ZClass Classes: APIError, APIInfo, Action, Alert, Application, AuthenticationError, Config, ConfigurationError, Connection, Event, Graph, Graphitem, History, Host, Hostgroup, Image, Item, Maintenance, Map, Mediatype, Proxy, ResponseCodeError, Runner, Screen, Script, Template, Trigger, User, Usergroup, Usermacro, Usermedia
Constant Summary collapse
- VERSION =
"0.1.2"
Class Method Summary collapse
Class Method Details
.init(&block) ⇒ Object
23 24 25 26 27 |
# File 'lib/zabby.rb', line 23 def self.init &block z = Zabby::Runner.instance z.run(&block) if block_given? z end |